<?php
// PEARで発生するE_STRICTエラー対策
error_reporting(E_ALL);

require_once __DIR__ . '/../silex.phar';
require_once "File/CSV.php";

$app = new Silex\Application();
// アプリケーション設定(csvファイルのパス)
$app['file'] = __DIR__ . '/articles.csv';
// twigエクステンション登録
$app->register(new Silex\Extension\TwigExtension(), array(
    'twig.path'       => __DIR__.'/../views',
    'twig.class_path' => __DIR__.'/../vendor',
));
// CSVデータ取得処理
$app['csv'] = $app->protect(function($file) use($app) {
    $config = File_CSV::discoverFormat($file);
    $articles = array();
    while ($fields = File_CSV::read($file, $config)) {
        $articles[$fields[0]] = $fields;
    }
    return $articles;
});
// 一覧表示
$app->get('/news', function (Silex\Application $app) {
   $csv = $app['csv'];
   $articles = $csv($app['file']);
   return $app['twig']->render('list.twig', compact('articles'));
});
// 記事詳細表示
$app->get('/news/{id}', function (Silex\Application $app, $id){
   $csv = $app['csv'];
   $articles = $csv($app['file']);
   if (!isset($articles[$id])) {
       $app->abort(404);
   }
   $article = ($articles[$id])?: array();
   return $app['twig']->render('detail.twig', compact('article'));
})
->assert('id', '\d{4}-\d{2}-\d{2}');
// エラー時
$app->error(function (\Exception $e, $code) use ($app) {
    return $app['twig']->render('error.twig');
});
// アプリケーション実行
$app->run();